import { build } from 'esbuild';
import { resolve } from 'path';
import { cacheFilePath } from '../config.ts';

export type Opts = {
  inputCode: string;
  id: string;
};

/**
 * 转换代码为 MJS
 * @param opts
 * @returns
 */
export async function transformToMJS(opts: Opts) {
  const { inputCode } = opts;
  const outputPath = resolve(cacheFilePath, `${opts.id}.mjs`);
  try {
    // 1. 使用 esbuild 转换代码
    const result = await build({
      stdin: {
        contents: inputCode,
        resolveDir: process.cwd(), // 当前目录为基准路径，用于解析文件路径
        loader: 'ts',
      },
      format: 'esm', // 输出为 ESM 格式
      outfile: outputPath, // 输出文件路径
      // bundle: true, // 启用打包
      platform: 'node', // 指定平台为 node
      // external: ['node_modules/*'], // 排除所有 node_modules 下的依赖
    });
    console.log(`转换完成，文件已保存到: ${outputPath}`);
    return { code: 200, outputPath };
  } catch (e) {
    console.error('transformToMJS error', e);
    return {
      code: 500,
      message: e.message,
    };
  }
}
