import { DataTypes, Model, Op } from 'sequelize';
import { sequelize } from '@/modules/sequelize.ts';

export type DevData = {
  cwd?: string; // 当前工作目录
  command: string; // 启动命令
  type: 'shell' | 'script'; // 启动类型
  env?: Record<string, string>; // 环境变量
  keepalive?: boolean; // 是否保持运行, 让用户知道是不是保持运行的
  code?: string; // 代码
  codeHash?: string; // 代码hash
  codePath?: string; // 代码路径, 转成 code 的路径
  codeStatus?: 'success' | 'error'; // 转换状态
  status: 'active' | 'inactive'; // 状态, 是否生成codePath
  path?: string; // esbuild 打包路径，用于 node 启动, vite 配置 esbuild 配置，rollup配置路径等
  scripts?: {
    [key: string]: string;
  };
};
export type Dev = Partial<InstanceType<typeof DevModel>>;

/**
 * @description 本地开发 配置启动和程序关闭
 */
export class DevModel extends Model {
  declare id: string;
  declare title: string;
  declare key: string;
  declare description: string;
  declare data: DevData;
}
DevModel.init(
  {
    id: {
      type: DataTypes.UUID,
      primaryKey: true,
      defaultValue: DataTypes.UUIDV4,
    },
    title: {
      type: DataTypes.TEXT,
      allowNull: false,
      defaultValue: '',
    },
    key: {
      type: DataTypes.TEXT,
      allowNull: false,
      defaultValue: '',
    },
    description: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    data: {
      type: DataTypes.JSON,
      allowNull: false,
      defaultValue: {},
    },
  },
  {
    sequelize,
    paranoid: true,
    modelName: 'local_dev',
  },
);

await DevModel.sync({
  alter: true,
  logging: false,
}).catch((e) => {
  console.error('DevModel sync error', e);
});
